@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
 import logging
-from urllib.parse import urlparse
 
-from flask import jsonify
+from flask import current_app, jsonify
 from jsonschema import ValidationError
 from patientMatcher.__version__ import __version__
 from patientMatcher.auth.auth import authorize
@@ -16,12 +15,24 @@ from patientMatcher.utils.stats import general_metrics
 LOG = logging.getLogger(__name__)
 
 
+def populate_index_data():
+    """Populate the dictionary used to display the server index page"""
+    data = dict(
+        node_stats=metrics(),
+        node_disclaimer=current_app.config.get("DISCLAIMER"),
+        node_contacts=current_app.config.get("ADMINS"),
+        connected_nodes=len(get_nodes(current_app.db)),
+        software_version=__version__,
+    )
+    return data
+
+
 def heartbeat(disclaimer):
     """Return a heartbeat as defined here:https://github.com/ga4gh/mme-apis/blob/master/heartbeat-api.md"""
 
     hbeat = {
         "heartbeat": {
-            "production": True,
+            "production": current_app.config.get("TESTING", "True") in ["False", False],
             "version": __version__,
             "accept": [
                 "application/vnd.ga4gh.matchmaker.v1.0+json",
@@ -33,9 +44,9 @@ def heartbeat(disclaimer):
     return hbeat
 
 
-def metrics(database):
+def metrics():
     """return database metrics"""
-    db_metrics = general_metrics(database)
+    db_metrics = general_metrics(current_app.db)
     return db_metrics
 
 
